@@ -1,9 +1,9 @@
-cem.match <- function (data, verbose = 0) 
+cem.match <- function (data, verbose = 1) 
 {
     vnames <- colnames(data)
     n <- dim(data)[1]
     nv <- dim(data)[2]
-    if (verbose > 1) {
+    if (verbose >= 1) {
         cat("\nmatching on variables:")
         cat(paste(vnames))
         cat("\n")
